@@ -9,7 +9,9 @@ from Search import Ui_SearchWindow
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
+#mine
 RADIO_TIME_SEARCH_URL = 'http://opml.radiotime.com/Search.ashx?formats=wma,mp3,aac,real,ogg,qt&partnerId=mbn0p_mK&serial=%s&query=%s'
+
 RADIO_TIME_PRESETS_URL = 'http://opml.radiotime.com/Browse.ashx?formats=wma,mp3,aac,real,ogg,qt&c=presets&partnerId=mbn0p_mK&serial=%s'
 RADIO_TIME_PRESET_ACTION_URL = 'http://opml.radiotime.com/Preset.ashx?c=%s&%s'
 RADIO_TIME_REPORT_URL = 'http://opml.radiotime.com/Report.ashx?c=wizard&%s'
@@ -137,7 +139,7 @@ class SearchWindow(QMainWindow, Ui_SearchWindow):
 
     @pyqtSlot() # need this to only allow one call per menu selection
     def on_actionAbout_triggered(self):
-        QMessageBox.information(self, self.tr("About"), self.tr("RadioTimeToGo Version 0.0.6-1"))
+        QMessageBox.information(self, self.tr("About"), self.tr("RadioTimeToGo Version 0.0.7-2"))
 
 class ResultsWindow(QMainWindow, Ui_ResultsWindow):
 
@@ -180,21 +182,21 @@ class ResultsWindow(QMainWindow, Ui_ResultsWindow):
                 populate_results(url, 0, ui.results, self, True)
             else:
                 if os.path.isfile('/opt/kmplayer/bin/kmplayer') or os.path.isfile('/usr/bin/kmplayer'):
-                    os.system('dbus-send --print-reply --dest=com.nokia.kmplayer /com/nokia/kmplayer com.nokia.kmplayer.mime_open string:%s' % url)
+                    os.system('dbus-send --print-reply --dest=com.nokia.kmplayer /com/nokia/kmplayer com.nokia.kmplayer.mime_open string:"%s"' % url)
                     #playlist = urllib.urlopen(url)
                     #stream = playlist.readline()
-                    #os.system('dbus-send --print-reply --dest=com.nokia.mediaplayer /com/nokia/mediaplayer com.nokia.mediaplayer.mime_open string:%s' % stream)
+                    #os.system('dbus-send --print-reply --dest=com.nokia.mediaplayer /com/nokia/mediaplayer com.nokia.mediaplayer.mime_open string:"%s"' % stream)
                 elif os.path.isfile('/Applications/VLC.app/Contents/MacOS/VLC'):
                     print url
                     playlist = urllib.urlopen(url)
                     for line in playlist.readlines():
                         print line
-                    #os.system('/Applications/VLC.app/Contents/MacOS/VLC %s &' % url)
+                    #os.system('/Applications/VLC.app/Contents/MacOS/VLC "%s" &' % url)
                 elif os.path.isfile('c:/program files/VideoLAN/vlc/vlc.exe'):
                     playlist = urllib.urlopen(url)
                     for line in playlist.readlines():
                         print line
-                    #os.system('"c:/program files/VideoLAN/vlc/vlc.exe" %s' % url)
+                    #os.system('"c:/program files/VideoLAN/vlc/vlc.exe" "%s"' % url)
 
     def on_pushButtonAdd_released(self):
         if self.index >= 0:
